----[[   Change the following number (usually 280) to the desired width   ]]----
----[[ I don't recommend going below 232 (the size of the default target) ]]----

local targetWidth = 280 -- the desired width of the target frame

--[[ TargetFrameTextureFrame ]]

local frame = TargetFrame.textureFrame
local tex = TargetFrame.borderTexture
local cx = 232 -- default size
local cy = 100

-- Split TargetFrameTextureFrameTexture in half and anchor the right half
-- to the right of TargetFrame. icons like pvp/quest anchor to this
tex:ClearAllPoints()
tex:SetPoint("TOPRIGHT",frame)
tex:SetSize(cx/2,cy)
tex:SetTexCoord(0.546875,1,0,0.78125)

-- Create a "left cap" from the left quarter, attached to the left edge
local left = frame:CreateTexture(nil,"BACKGROUND")
left:SetSize(cx/4,cy)
left:SetPoint("TOPLEFT")
left:SetTexCoord(0.09375,0.3203125,0,0.78125)

-- Create a midsection of the remaining quarter stretched between the above
local mid = frame:CreateTexture(nil,"BACKGROUND")
mid:SetPoint("TOPLEFT",left,"TOPRIGHT")
mid:SetPoint("BOTTOMRIGHT",tex,"BOTTOMLEFT")
mid:SetTexCoord(0.3203125,0.546875,0,0.78125)

-- When TargetFrameTextureFrameTexture's texture changes (elite, minus, etc),
-- change the left cap and midsection to the same texture
hooksecurefunc(tex,"SetTexture",function(self,texture)
  left:SetTexture(texture)
  mid:SetTexture(texture)
end)

-- For addons like Avant UI that color the targetframe, also color the new textures
hooksecurefunc(tex,"SetVertexColor",function(self,...)
	left:SetVertexColor(...)
	mid:SetVertexColor(...)
end)
hooksecurefunc(tex,"SetGradientAlpha",function(self,...)
	left:SetGradientAlpha(...)
	mid:SetGradientAlpha(...)
end)
-- Retroactively apply colors already applied to target texture; there's no GetGradientAlpha :(
local r,g,b,a = tex:GetVertexColor()
left:SetVertexColor(r,g,b,a)
mid:SetVertexColor(r,g,b,a)

-- Bars get second anchors, to stretch them instead of a static width
TargetFrameNameBackground:SetPoint("TOPLEFT",TargetFrame,"TOPLEFT",6,-22)
TargetFrameHealthBar:SetPoint("TOPLEFT",TargetFrame,"TOPLEFT",6,-41)
TargetFrameManaBar:SetPoint("TOPLEFT",TargetFrame,"TOPLEFT",6,-52)
TargetFrameBackground:SetPoint("BOTTOMRIGHT",TargetFrame,"BOTTOMRIGHT",-106,35)

-- Entirely re-anchor the level indicator
TargetFrameTextureFrameLevelText:ClearAllPoints()
TargetFrameTextureFrameLevelText:SetPoint("CENTER",frame, "RIGHT",-53,-16)

hooksecurefunc("TargetFrame_UpdateLevelTextAnchor",function(self,targetLevel)
	TargetFrameTextureFrameLevelText:SetPoint("CENTER",frame,"RIGHT",-55+(targetLevel<100 and 1 or 0),-16)
end)

-- Entirely re-anchor the target name, stretching with the target frame
TargetFrameTextureFrameName:ClearAllPoints()
TargetFrameTextureFrameName:SetPoint("TOPLEFT", frame, "TOPLEFT", 8, -25)
TargetFrameTextureFrameName:SetPoint("BOTTOMRIGHT", frame, "TOPRIGHT", -110, -37)

--[[ Flash/ThreatIndicator ]]

-- Unlike the border texture above, the flash/threat glow has different texcoords,
-- sizes and positions for the three different frame types (normal, elite, minus)

local flash = TargetFrameFlash

-- Making a right cap here since main texture re-anchored to TOPLEFT for each target
flash.rightFlash = TargetFrame:CreateTexture(nil,"BACKGROUND")
flash.midFlash = TargetFrame:CreateTexture(nil,"BACKGROUND")

hooksecurefunc(flash,"SetTexture",function(self,texture)
	flash.rightFlash:SetTexture(texture)
  flash.midFlash:SetTexture(texture)
end)

-- Fortunately, default does a SetPoint after SetTexture/SetWidth/SetTexCoord, so
-- every change needed can be done in reaction to this.
hooksecurefunc(flash,"SetPoint",function(self,anchorPoint,relativeTo,relativePoint,xoff,yoff)
  local cx = self:GetWidth()
  local cy = self:GetHeight()
  local specificXoff -- right xoff specific for each frame type
  self:SetWidth(cx/2)
  self.rightFlash:SetWidth(cx/2)
  self.rightFlash:SetHeight(cy)
  self.midFlash:SetHeight(cy)
  if cy<100 then -- normal target
    self:SetTexCoord(0,0.47265625,0,0.181640625)
    self.rightFlash:SetTexCoord(0.47265625,0.9453125,0,0.181640625)
    self.midFlash:SetTexCoord(0.25,0.5,0,0.181640625)
    specificXoff = -38
  elseif cx>255 then -- "minus" target
    self:SetTexCoord(0,.5,0,1)
    self.rightFlash:SetTexCoord(.5,1,0,1)
    self.midFlash:SetTexCoord(0.25,0.5,0,1)
    specificXoff = -24
  elseif cy>100 then -- "elite" target
    self:SetTexCoord(0,0.47265625,0.181640625,0.400390625)
    self.rightFlash:SetTexCoord(0.47265625,0.9453125,0.181640625,0.400390625)
    self.midFlash:SetTexCoord(0.19,0.39,0.181640625,0.400390625)
    specificXoff = -34
  end
  self.rightFlash:SetPoint("TOPRIGHT",TargetFrame,"TOPRIGHT",specificXoff-xoff,yoff)
  self.midFlash:SetPoint("TOPLEFT",self,"TOPRIGHT")
  self.midFlash:SetPoint("BOTTOMRIGHT",self.rightFlash,"BOTTOMLEFT")
end)

-- When left side is shown, show the right cap and midsection
hooksecurefunc(flash,"Show",function(self)
  self.rightFlash:Show()
  self.midFlash:Show()
end)
-- When left side is hidden, hide the right cap and midsection
hooksecurefunc(flash,"Hide",function(self)
  self.rightFlash:Hide()
  self.midFlash:Hide()
end)
-- When left side is colored, color the right cap and midsection
hooksecurefunc(flash,"SetVertexColor",function(self,...)
  self.rightFlash:SetVertexColor(...)
  self.midFlash:SetVertexColor(...)
end)

-- TargetFrame:SetWidth() will now stretch the whole frame and its component parts
-- without stretching graphics (other than the midsections that fill in the gap)

TargetFrame:SetWidth(targetWidth)
